@@ -1582,8 +1582,8 @@ lineage_dict_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid
 distance_mat_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/sample_clustering_and_summary/rho_dicts/neg_euc_dist.hdf5"
 cluster_dict_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/sample_clustering_and_summary/clustering_plots.pkl"
 subject_network_file = '/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/sample_clustering_and_summary/cell_embedding.graphpkl'
-cluster_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/sample_clustering_and_summary/sample_k_means_groups.txt"
-mean_express_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/sample_clustering_and_summary/k_group_means.txt"
+cluster_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/sample_clustering_and_summary/sample_k_means_groups.tsv"
+mean_express_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/sample_clustering_and_summary/k_group_means.tsv"
 out_dir = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/lineage_analysis/trajectory_plots/"
 goi_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/goi.txt"
 human_symbol_dict_file = "/home/scott/Documents/scRNAseq/human_breast_cancer_organoid_GSE113196/analysis/annotations.pkl"
