@@ -84,14 +84,6 @@ if False:#args.sparse:
 	#dset = csc_matrix((len(ID_list),cols-1))
 	#dset = f.create_dataset("infile", (len(ID_list),cols-1), dtype=csc_matrix)
 else:
-<<<<<<< HEAD
-	dset = f.create_dataset("infile",
-		                    (len(ID_list),cols-1),
-		                    dtype=np.float32,
-		 			        fillvalue=0.,
-                            compression='gzip',
-                            compression_opts=9)
-=======
 	if args.sparse:
 		dset = f.create_dataset("infile",
 			                    (len(ID_list),cols-1),
@@ -103,7 +95,6 @@ else:
 		dset = f.create_dataset("infile",
 			                    (len(ID_list),cols-1),
 			                    dtype=np.float32)
->>>>>>> d362fc61e0a62383450b5d042be8c77c99e4bbc6
 
 ## populate dset with the values from the input dataset
 line_count = 0
